<?php
/**
 * 新規ページ追加画面クラス
 *
 * 新規ページ追加画面を実現するためのクラス
 *
 * @package   simplepage
 * @author    Risoluto Developers
 * @license   http://opensource.org/licenses/bsd-license.php new BSD license
 * @copyright (C) 2008-2011 Risoluto Developers / All Rights Reserved.
 */

  /**
   * 基底クラス
   */
  require_once( "simplepage_base.inc" );

  class pageadd_entry extends simplepage_base
  {
    //------------------------------------------------------//
    // クラス変数定義
    //------------------------------------------------------//
    /**
     * データベース操作クラスインスタンスを保持する変数
     * @access private
     * @var    object
     */
    private $obj_db;
    /**
     * ユーティリティクラスインスタンスを保持する変数
     * @access private
     * @var    object
     */
    private $obj_conf;
    /**
     * 取得データを保持する変数
     * @access private
     * @var    object
     */
    private $gotDat;

    //------------------------------------------------------//
    // クラスメソッド定義
    //------------------------------------------------------//
    /**
     * コンストラクタメソッド
     *
     * コンストラクタメソッド
     *
     * @param     void なし
     * @return    void なし
     */
    public function __construct()
    {
    } // end of function:__construct()

    /**
     * クローンメソッド
     *
     * クローンメソッド
     *
     * @param     void なし
     * @return    void なし
     */
    public function __clone()
    {
    } // end of function:__clone()

    /**
     * modelメソッド（モデル）
     *
     * データ取得等のモデルに相当する部分の処理を行う
     *
     * @param     void なし
     * @return    boolean ファンクション実行結果（ true：正常終了 / false: 異常終了 ）
     */
    public function model()
    {
      // 必要なインスタンスを生成
      $this->obj_conf = new RisolutoConf();
      $this->obj_conf->parse( RISOLUTO_CONF . 'risoluto.ini' );

      // スーパバイザセッション又はアドミンセッションが存在しない場合は、
      // ログイン画面に遷移する
      if ( ! $this->obj_util->is_Admin() )
      {
        $this->obj_util->redirectTo( $this->obj_adminconf->get( 'COMMON', 'login_act'  )
                                   , $this->obj_adminconf->get( 'COMMON', 'login_cage' ) );
        return false;
      } // end of if



      //------------------------------------------------------------------------
      // セッション情報の取得
      //------------------------------------------------------------------------

      // セッションからエラーメッセージと入力値を取得し、削除する
      $this->gotDat[ 'errMsg' ] = $this->obj_sess->sessLoad( $this->obj_sess->sessLoad( 'currentcage' ) );
      $this->obj_sess->sessRevoke( $this->obj_sess->sessLoad( 'currentcage' ) );



      //------------------------------------------------------------------------
      // デフォルトのヘッダ情報を取得
      //------------------------------------------------------------------------
      if ( !isset( $this->gotDat[ 'errMsg' ][ 'headerinfo' ] ) or empty( $this->gotDat[ 'errMsg' ][ 'headerinfo' ] ) )
      {
        // データベースに接続する
        // データベース操作クラスのインスタンスを生成する
        $this->obj_db = new RisolutoDb();

        // データベースに接続する
        if ( $this->obj_db->dbConnect( $this->obj_conf->get( 'DBS', 'DEFAULT_DSN' ) ) )
        {
          // SQL文を組み立てる
          $sql =<<<End_Of_SQL

              SELECT `headers`.`header_id`    -- header ID
                   , `headers`.`robot_index`  -- robots(index)
                   , `headers`.`robot_follow` -- robots(follow)
                   , `headers`.`title`        -- title
                   , `headers`.`description`  -- description
                   , `headers`.`keywords`     -- keywords
                   , `headers`.`author`       -- author
                   , `headers`.`javascript`   -- javascript
                   , `headers`.`css`          -- css
                   , `headers`.`favicon`      -- favicon
                FROM `risoluto_t_headerinfo` headers
               WHERE `headers`.`cage` = ?
                 AND `headers`.`act`  = 'pageview'

End_Of_SQL;

          // パラメタも用意する
          $param = array(
                          $this->mycage
                        );

          // SQLの実行に失敗した場合は、例外を投げる
          $tmp_result = $this->obj_db->dbGetRow( $sql, $param );
          if ( PEAR::isError( $tmp_result ) )
          {
            // 接続をクローズする
            $this->obj_db->dbDisConnect();
            throw new Exception( 'default header info Get Failure' );
            return false;
          } // end of if
          // 入力された値と、取得した値を使ってデータをインサートする
          else
          {
            $this->gotDat[ 'errMsg' ][ 'headerinfo' ] = $tmp_result;
          } // end of else

        } // end of if
        // データベースに接続できなかった場合は、例外を投げる
        else
        {
          throw new Exception( 'DB Connection Failure' );
          return false;
        } // end of else

      } // end of if



      //------------------------------------------------------------------------
      // CKEditorが存在すれば使用する
      //------------------------------------------------------------------------
      clearstatcache();
      $this->gotDat[ 'is_ckeditor' ] = file_exists( RISOLUTO_DOCROOT . '/ckeditor/' );

      return true;
    } // end of function:model()

    /**
     * viewメソッド（モデル）
     *
     * テンプレート関連処理等のビューに相当する部分の処理を行う
     *
     * @param     void なし
     * @return    boolean ファンクション実行結果（ true：正常終了 / false: 異常終了 ）
     */
    public function view()
    {
      // アサイン
      $this->smarty->assign ( 'header',             $this->obj_util->getHeader() );

      $this->smarty->assign ( 'menu_cage',          $this->obj_adminconf->get( 'COMMON', 'menu_cage' ) );
      $this->smarty->assign ( 'menu_act',           $this->obj_adminconf->get( 'COMMON', 'menu_act'  ) );

      $this->smarty->assign ( 'mycage',             $this->mycage );

      $this->smarty->assign ( 'is_ckeditor',        $this->gotDat[ 'is_ckeditor' ] );
      $this->smarty->assign ( 'base_url',           $this->obj_util->getBaseUrl() );

      $this->smarty->assign ( 'errMsg',             $this->gotDat[ 'errMsg' ][ 'message'    ] );
      $this->smarty->assign ( 'entered_body',       $this->gotDat[ 'errMsg' ][ 'body'       ] );
      $this->smarty->assign ( 'entered_slug',       $this->gotDat[ 'errMsg' ][ 'slug'       ] );
      $this->smarty->assign ( 'entered_headerinfo', $this->gotDat[ 'errMsg' ][ 'headerinfo' ] );

      // 表示
      $this->smarty->display( 'pageadd_entry.tpl' );

      return true;

    } // end of function:view()

  } // end of class:pageadd_entry

?>
